==> ibm_ai_openscale-1.0.287-py3-none-any.whl: tests/models/tensorflow.py <==
# ----------------------------------------------------------------------------------------------------
# IBM Confidential
# OCO Source Materials
# 5900-A3Q, 5737-J33
# Copyright IBM Corp. 2018
# The source code for this program is not published or other-wise divested of its trade 
# secrets, irrespective of what has been deposited with the U.S.Copyright Office.
# ----------------------------------------------------------------------------------------------------

from .AbstractModel import AbstractModel
import os
import xgboost as xgb
import scipy


class Unknown(AbstractModel):

    model_path = os.path.join(os.getcwd(), 'artifacts', 'tf-saved_model.tar.gz')

    def publish_to_wml(self, wml_client):
        return wml_client.repository.store_model(model=self.model_path, meta_props=self.get_model_props(wml_client))

    def get_model_props(self, wml_client):
        return {
            wml_client.repository.ModelMetaNames.NAME:"AIOS TF model",
            wml_client.repository.ModelMetaNames.AUTHOR_NAME:"John Smith",
            wml_client.repository.ModelMetaNames.FRAMEWORK_NAME:"tensorflow",
            wml_client.repository.ModelMetaNames.FRAMEWORK_VERSION:"1.5",
            wml_client.repository.ModelMetaNames.RUNTIME_NAME:"python",
            wml_client.repository.ModelMetaNames.RUNTIME_VERSION:"3.5"
        }

    def get_scoring_payload(self):
        scoring_data = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 18, 18, 18,
                        126, 136, 175, 26, 166, 255, 247, 127, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 30, 36, 94, 154, 170, 253,
                        253, 253, 253, 253, 225, 172, 253, 242, 195, 64, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 49, 238, 253, 253, 253,
                        253, 253, 253, 253, 253, 251, 93, 82, 82, 56, 39, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 219, 253,
                        253, 253, 253, 253, 198, 182, 247, 241, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        80, 156, 107, 253, 253, 205, 11, 0, 43, 154, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 14, 1, 154, 253, 90, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 139, 253, 190, 2, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 190, 253, 70,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 35,
                        241, 225, 160, 108, 1, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 81, 240, 253, 253, 119, 25, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 45, 186, 253, 253, 150, 27, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 16, 93, 252, 253, 187,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 249,
                        253, 249, 64, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 46, 130,
                        183, 253, 253, 207, 2, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 39, 148,
                        229, 253, 253, 253, 250, 182, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 114,
                        221, 253, 253, 253, 253, 201, 78, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 66,
                        213, 253, 253, 253, 253, 198, 81, 2, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 171,
                        219, 253, 253, 253, 253, 195, 80, 9, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 55, 172,
                        226, 253, 253, 253, 253, 244, 133, 11, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        136, 253, 253, 253, 212, 135, 132, 16, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0]

        return {
            'values':
                [
                    scoring_data,
                    scoring_data
                ]
        }

==> ibm_ai_openscale-1.0.321-py3-none-any.whl: tests/models/tensorflow.py <==
# ----------------------------------------------------------------------------------------------------
# IBM Confidential
# OCO Source Materials
# 5900-A3Q, 5737-J33
# Copyright IBM Corp. 2018
# The source code for this program is not published or other-wise divested of its trade 
# secrets, irrespective of what has been deposited with the U.S.Copyright Office.
# ----------------------------------------------------------------------------------------------------

from .AbstractModel import AbstractModel
import os
import xgboost as xgb
import scipy


class Structured(AbstractModel):
    model_name = "AIOS TF Structured Model"
    deployment_name = "AIOS TF Structured Deployment"

    model_path = os.path.join(os.getcwd(), 'artifacts', 'tf-saved_model.tar.gz')

    def publish_to_wml(self, wml_client):
        return wml_client.repository.store_model(model=self.model_path, meta_props=self.get_model_props(wml_client))

    def get_model_props(self, wml_client):
        return {
            wml_client.repository.ModelMetaNames.NAME: self.model_name,
            wml_client.repository.ModelMetaNames.AUTHOR_NAME: "John Smith",
            wml_client.repository.ModelMetaNames.FRAMEWORK_NAME: "tensorflow",
            wml_client.repository.ModelMetaNames.FRAMEWORK_VERSION: "1.5",
            wml_client.repository.ModelMetaNames.RUNTIME_NAME: "python",
            wml_client.repository.ModelMetaNames.RUNTIME_VERSION: "3.5"
        }

    def get_scoring_payload(self):
        scoring_data = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 18, 18, 18,
                        126, 136, 175, 26, 166, 255, 247, 127, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 30, 36, 94, 154, 170, 253,
                        253, 253, 253, 253, 225, 172, 253, 242, 195, 64, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 49, 238, 253, 253, 253,
                        253, 253, 253, 253, 253, 251, 93, 82, 82, 56, 39, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 219, 253,
                        253, 253, 253, 253, 198, 182, 247, 241, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        80, 156, 107, 253, 253, 205, 11, 0, 43, 154, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 14, 1, 154, 253, 90, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 139, 253, 190, 2, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 190, 253, 70,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 35,
                        241, 225, 160, 108, 1, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 81, 240, 253, 253, 119, 25, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 45, 186, 253, 253, 150, 27, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 16, 93, 252, 253, 187,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 249,
                        253, 249, 64, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 46, 130,
                        183, 253, 253, 207, 2, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 39, 148,
                        229, 253, 253, 253, 250, 182, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 114,
                        221, 253, 253, 253, 253, 201, 78, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 66,
                        213, 253, 253, 253, 253, 198, 81, 2, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 171,
                        219, 253, 253, 253, 253, 195, 80, 9, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 55, 172,
                        226, 253, 253, 253, 253, 244, 133, 11, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        136, 253, 253, 253, 212, 135, 132, 16, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                        0, 0, 0, 0]

        return {
            'values':
                [
                    scoring_data,
                    scoring_data
                ]
        }
